import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { lastValueFrom } from 'rxjs';
import { DataType } from '../../../models/DataType.model';
import { Structure } from '../../../models/structure.model';
import { DataService } from '../../../services/data.service';

@Component({
  selector: 'app-structure-list-data',
  templateUrl: './structure-list-data.component.html',
  styleUrls: ['./structure-list-data.component.scss'],
})
export class StructureListDataComponent implements OnInit {
  public dataType: DataType;
  public structures: Structure[];

  constructor(
    private route: ActivatedRoute,
    private dataService: DataService,
  ) {}

  async ngOnInit(): Promise<void> {
    this.route.queryParams.subscribe(async (params) => {
      const slug = params.data;
      const CTMs = params.ctm?.split(',');
      const inseeCodes = params.inseeCode?.split(',');

      this.dataType = this.dataService.structures.find((dataType) => dataType.slug === slug);

      // Get structures using specified filter for this DataType
      this.structures = await lastValueFrom(this.dataService.getStructures(this.dataType, CTMs, inseeCodes));
    });
  }
}
